@@ -1,32 +1,34 @@
 package File::Edit::Portable;
-use 5.006;
+use 5.012;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 
 sub new {
     return bless {}, shift;
 }
-sub pread {
+sub read {
 
     my $self = shift;
 
     $self->_config(@_);
 
+    $self->{is_read} = 1;
+
     my $file = $self->{file};
     my $testing = $self->{testing};
 
     if (! $file){ 
-        croak "pread() requires a file name sent in!";
+        croak "read() requires a file name sent in!";
     }
 
     $self->recsep($file);
 
     open my $fh, '<', $file
-      or croak "pread() can't open the file $file!: $!";
+      or croak "read() can't open the file $file!: $!";
 
     binmode $fh, ':raw';
     my @contents = <$fh>;
@@ -41,7 +43,7 @@ sub pread {
 
     return @contents;
 }
-sub pwrite {
+sub write {
 
     my $self = shift;
     my $p = $self->_config(@_);
@@ -54,6 +56,10 @@ sub pwrite {
 
     $file = $copy if $copy;
 
+    if (! $self->{is_read}){
+        $self->recsep($file);
+    }
+
     open my $wfh, '>', $file or die $!;
 
     binmode $wfh, ':raw';
@@ -121,11 +127,11 @@ File::Edit::Portable - Read and write files while keeping the original line-endi
 
     my $rw = File::Edit::Portable->new;
 
-    my @contents = $rw->pread(file => 'file.txt');
+    my @contents = $rw->read(file => 'file.txt');
 
     push @contents, 'line 1', 'line 2';
 
-    $rw->pwrite(file => 'file.txt', contents => \@contents);
+    $rw->write(file => 'file.txt', contents => \@contents);
 
     $hex_record_separator = $rw->recsep('file');
 
@@ -135,7 +141,7 @@ This module will read in a file, and keep track of the file's current line endin
 
 Uses are for dynamically reading/writing files while on one Operating System, but you don't know that the record separator (line endings) are platform-standard.
 
-You're returned an array with all of the lines of the file on read. You can them manipulate it, and then pass it back for re-writing the file (or a copy).
+You're returned an array with all of the lines of the file on read. You can then manipulate it, and then pass it back for re-writing the file (or a copy).
 
 =head1 METHODS
 
@@ -143,24 +149,24 @@ You're returned an array with all of the lines of the file on read. You can them
 
 Returns a new C<File::Edit::Portable> object.
 
-=head2 C<pread>
+=head2 C<read>
 
 Opens a file and extracts its contents, returning an array of the files contents where each line of the file is a separate element in the array.
 
 Parameters: C<file =E<gt> 'filename'>
 
 
-=head2 C<pwrite>
+=head2 C<write>
 
 Writes the data back to the original file, or alternately a copy of the file. Returns 1 on success.
 
 Parameters: 
 
-C<file =E<gt> 'file'>: Not needed if you've used C<pread()> to open the file. 
+C<file =E<gt> 'file'>: Not needed if you've used C<read()> to open the file. 
 
 C<copy =E<gt> 'file2'>: Set this if you want to write to an alternate file, rather than the original.
 
-C<contents =E<gt> \@contents>: Mandatory, should contain a reference to the array that was returned by C<pread()>.
+C<contents =E<gt> \@contents>: Mandatory, should contain a reference to the array that was returned by C<read()>.
 
 =head2 C<recsep('file')>
 
@@ -172,7 +178,7 @@ Steve Bertrand, C<< <steveb at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-file-rw-portable at rt.cpan.org>, or through
+Please report any bugs or feature requests to C<bug-file-edit-portable at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Edit-Portable>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
